@@ -1,7 +1,7 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable;
-$Mojo::UserAgent::Mockable::VERSION = '1.55';
+$Mojo::UserAgent::Mockable::VERSION = '1.56';
 use warnings::register;
 
 use Carp;
@@ -234,6 +234,10 @@ sub _init_record {
                 finish => sub {
                     my $tx = shift;
                     push @{ $self->{'_transactions'} }, $tx;
+
+                    # 15: During global destruction the $tx object may no longer exist
+                    # so save now
+                    $self->save($self->file);
                 },
             );
             1;
@@ -250,14 +254,6 @@ sub _load_transactions {
     return \@transactions;
 }
 
-# In record mode, write out the recorded file
-sub DESTROY {
-    my $self = shift;
-
-    if ( $self->_mode eq 'record' ) {
-        $self->save( $self->file );
-    }
-}
 1;
 
 __END__
@@ -272,7 +268,7 @@ Mojo::UserAgent::Mockable - A Mojo User-Agent that can record and play back requ
 
 =head1 VERSION
 
-version 1.55
+version 1.56
 
 =head1 SYNOPSIS
 
@@ -576,6 +572,8 @@ Where the magic happens
 
 =head1 CONTRIBUTORS
 
+Mike Eve L<https://github.com/ungrim97>
+
 Phineas J. Whoopee L<https://github.com/antoniel123>
 
 Marc Murray L<https://github.com/marcmurray>
