@@ -1,7 +1,7 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable::Serializer;
-$Mojo::UserAgent::Mockable::Serializer::VERSION = '1.55';
+$Mojo::UserAgent::Mockable::Serializer::VERSION = '1.56';
 use warnings::register;
 
 use Carp;
@@ -42,7 +42,8 @@ sub _serialize_tx {
         class    => ref $transaction,
     };
     for my $event ( keys %{ $transaction->{'events'} } ) {
-        next if $event eq 'pre_freeze' or $event eq 'post_freeze' or $event eq 'resume';
+        next if $event eq 'pre_freeze' or $event eq 'post_freeze' or $event eq 'resume' 
+            or $event eq 'finish'; # 'finish' comes from Mojo::IOLoop; we probably don't need to serialize it
         carp(qq{Subscriber for event "$event" not serialized}) if warnings::enabled;
         push @{ $slush->{'events'} }, $event;
     }
@@ -231,7 +232,7 @@ Mojo::UserAgent::Mockable::Serializer - A class that serializes Mojo transaction
 
 =head1 VERSION
 
-version 1.55
+version 1.56
 
 =head1 SYNOPSIS
 
